@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/game.h,v 12.0 2009/06/28 20:43:12 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/game.h,v 12.1 2012/02/01 14:10:41 jcb Rel $
  * game.h
  * This file contains the game data structure and associated definitions,
  * and prototypes for some functions that work on it.
@@ -323,10 +323,9 @@ GameOptionEntry *game_get_default_option_entry(GameOption option, char *name);
 
 /* get an option value. First look in the game table; if that fails,
    look in the default table; if that fails return the default default.
-   Returns the value ((char *) for GOTString) as a (void *).
 */
 
-void *game_get_option_value(Game *g, GameOption option, char *name);
+GameOptionValue game_get_option_value(Game *g, GameOption option, char *name);
 
 /* set an option in table. Function will allocate space as required */
 int game_set_option_in_table(GameOptionTable *t, GameOptionEntry *e);
