@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.2 2014/01/03 14:18:15 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.4 2025/04/25 20:37:52 jcb Exp $
  * greedy.c
  * This is a computer player. Currently offensive only.
  * Options not documented.
@@ -15,8 +15,6 @@
  *                                                           *
  *************************************************************/
  
-static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.2 2014/01/03 14:18:15 jcb Exp $";
-
 static int debugeval = 0;
 #include <stdlib.h>
 #include <stdio.h>
@@ -24,8 +22,12 @@ static int debugeval = 0;
 #include "client.h"
 #include "sysdep.h"
 
+static const char rcs_id[] UNUSED = "$Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.4 2025/04/25 20:37:52 jcb Exp $";
+
 #include "version.h"
 
+static double normal_random_double(double sigma);
+
 static double magic[28+13] = 
   {
     12, 2, 1, 0.15, 1, 4, 4.97465626805558, 4, 1, 0.00638363133042069,
@@ -41,7 +43,7 @@ static double *magic2 = &magic[28];
 
 /* is this tile a doubling tile (or scoring pair) */
 #define is_doubler(t) (is_dragon(t) || (is_wind(t) && \
- (suit_of(t) == our_player->wind || suit_of(t) == the_game->round)))
+ (value_of(t) == our_player->wind || value_of(t) == the_game->round)))
 
 Game *the_game;
 int our_id = 0;
@@ -109,6 +111,9 @@ enum {pungbase,pairbase,chowbase,seqbase,sglbase,
    by this amount for it to be chosen */
 static double hysteresis = 4.0; 
 
+/* standard deviation of noise added to eval values to reduce skill */
+static double randomness = 0.0;
+
 
 /* Used to note availability of tiles */
 static int tilesleft[MaxTile];
@@ -186,6 +191,9 @@ int main(int argc, char *argv[]) {
     } else if ( strcmp(argv[i],"--suitness") == 0 ) {
       if ( ++i == argc ) usage(argv[0],"missing argument to --suitness");
       parsefloatlist(argv[i],suitness);
+    } else if ( strcmp(argv[i],"--randomness") == 0 ) {
+      if ( ++i == argc ) usage(argv[0],"missing argument to --randomness");
+      parsefloatlist(argv[i],randomness);
     } else if ( strcmp(argv[i],"--magic") == 0 ) {
       FILE *f;
       unsigned int j;
@@ -321,6 +329,7 @@ static int despatch_line(char *line) {
       send_packet(&plgom);
     }
     /* and then ... */
+    // fall through
   case CMsgNewRound:
   case CMsgNewHand:
     game_handle_cmsg(the_game,cm);
@@ -955,7 +964,8 @@ static double eval(Tile *tp,strategy *strat,double *stratpoints,
   Tile copy[MAX_CONCEALED+1],copy2[MAX_CONCEALED+1];
   int i;
   double mval = 0, pval = 0, val = 0,
-    pvalr = 0, mvalr = 0, valr = 0;
+    // why are these set but not used? What were they for?
+    pvalr UNUSED = 0, mvalr UNUSED = 0, valr = 0;
   int ppr, mpr; int spr;
   char prefix[200];
   static char totbuf[200];
@@ -1318,8 +1328,10 @@ static double evalhand(PlayerP p,strategy *strat) {
       break;
     case ClosedKong:
       sval += stratpoints[exposedpungpenalty]; /* cancel the penalty later */
+      // fall through
     case Kong:
       sval += stratpoints[kongbonus];
+      // fall through
     case Pung:
     case ClosedPung:
       sval -= stratpoints[exposedpungpenalty];
@@ -1358,17 +1370,38 @@ static double evalhand(PlayerP p,strategy *strat) {
     val += stratpoints[pairbase];
   }
   val *= stratpoints[weight];
-#if 0 /* randomization seems to be a lose */
-  /* now add a small random offset */
-  r = (2.0*rand())/RAND_MAX - 1.0;
-  r = 4*r*r;
-  return val+r;
-#else
+  val += normal_random_double(randomness);
   if ( debugeval ) fprintf(debugf,"Value %.2f\n",val);
   return val;
-#endif
 }
 
+/* random double via box muller */
+static double normal_random_double(double sigma) {
+  if ( sigma == 0.0 ) return 0.0;
+  static int second = 0;
+  static double z1;
+  if ( second ) { second = 0; return z1; }
+  second = 1;
+  double x = (double)
+#ifdef WIN32
+  rand
+#else
+  random
+#endif
+    () / RAND_MAX,
+    y = (double)
+#ifdef WIN32
+  rand
+#else
+  random
+#endif
+    () / RAND_MAX,
+    z = sqrt(-2 * log(x)) * cos(2 * M_PI * y);
+  z1 = sqrt(-2 * log(x)) * sin(2 * M_PI * y);
+  return sigma*z;
+}
+
+
 /* compute the number of ways a calling hand can go out */
 static int chances_to_win(PlayerP p) {
   Tile t;
