@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/gui.h,v 12.7 2020/05/23 10:07:46 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/gui.h,v 12.9 2025/04/25 17:40:34 jcb Exp $
  * gui.h
  * type defns and forward declarations for the gui module.
  */
@@ -355,7 +355,7 @@ extern GtkWidget *open_dialog;
 extern GtkWidget *openmenuentry, *newgamemenuentry, *resumegamemenuentry, 
   *savemenuentry, *saveasmenuentry, *closemenuentry, *gameoptionsmenuentry;
 extern GtkWidget *openallowdisconnectbutton,*opensaveonexitbutton,*openrandomseatsbutton,
-  *openplayercheckboxes[3],*openplayernames[3],*openplayeroptions[3],*opentimeoutspinbutton;
+  *openplayercheckboxes[3],*openplayernames[3],*openplayeroptions[3],*opentimeoutspinbutton, *opendifficultyspinbutton;
 
 /* dialog box for action when it's our turn.
    Actions: Discard  Kong  Add to Pung  Mah Jong
@@ -407,13 +407,12 @@ extern int display_size; /* and this is the preference value for pdispwidth */
 extern int square_aspect; /* force a square table */
 extern char address[]; /* server address */
 extern char name[]; /* player's name */
+extern int difficulty; /* robot difficulty level */
 extern char main_font_name[]; /* font used in all dialogs etc */
 extern char text_font_name[]; /* font used for text in windows */
 extern char fallback_text_font_name[]; /* one that worked */
-#ifdef GTK2
 extern int use_system_gtkrc; /* as it says */
 extern char gtk2_rcfile[512]; /* gtkrc file to use */
-#endif
 extern char table_colour_name[]; /* colour of the table background */
 extern int animate; /* do fancy animation */
 extern int nopopups; /* suppress automatic popup of message/scoring windows */
