@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/lazyfixed.c,v 12.0 2009/06/28 20:43:12 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/lazyfixed.c,v 12.1 2020/05/30 17:27:18 jcb Exp $
  * lazyfixed.c
  * A slight variation on the GTK+ fixed widget.
  * It doesn't call queue_resize when children removed;
@@ -59,12 +59,12 @@ lazy_fixed_get_type (void)
 static void
 lazy_fixed_class_init (GtkFixedClass *class)
 {
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
+  // GtkObjectClass *object_class;
+  // GtkWidgetClass *widget_class;
   GtkContainerClass *container_class;
 
-  object_class = (GtkObjectClass*) class;
-  widget_class = (GtkWidgetClass*) class;
+  // object_class = (GtkObjectClass*) class;
+  // widget_class = (GtkWidgetClass*) class;
   container_class = (GtkContainerClass*) class;
 
   parent_class = gtk_type_class (GTK_TYPE_FIXED);
