@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/protocol.h,v 12.1 2011/08/27 21:30:00 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/protocol.h,v 12.3 2020/05/16 12:49:46 jcb Exp $
  * protocol.h
  * defines the messages passed between players and controller
  */
@@ -113,6 +113,16 @@ typedef struct _GameOptionEntry {
   void *userdata; /* field for client use */
 } GameOptionEntry;
 
+/* This type is for use externally. It's the same as the union type in the 
+   option entry, except that the string is returned as a pointer.
+*/
+typedef union _GameOptionValue {
+  bool optbool;
+  int optint;
+  unsigned int optnat;
+  int optscore;
+  char *optstring;
+} GameOptionValue;
 
 /* The fundamental principle is that players cannot change the state
    of the game---including their own hand. They send a message to
@@ -135,7 +145,7 @@ typedef struct _GameOptionEntry {
 */
 
 /* This define gives the protocol version implemented in this file */
-#define PROTOCOL_VERSION 1110
+#define PROTOCOL_VERSION 1111
 
 /* This global variable, found in protocol.c, is used by many functions
    to determine the protocol version currently being used.
@@ -924,7 +934,7 @@ typedef struct _CMsgGameOverMsg {
 typedef struct _PMsgSetGameOptionMsg {
   PlayerMsgType type; /* PMsgSetGameOption */
   word16 optname;
-  char *optvalue;
+  char *optvalue; /* this *is* a char*, it's a text representation of value */
 } PMsgSetGameOptionMsg;
 
 /* Message to inform players of a game option value */
