@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.h,v 12.2 2020/05/26 09:34:13 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.h,v 12.3 2025/09/06 12:12:39 jcb Exp $
  * sysdep.h
  * Miscellaneous system stuff that may require attention
  * by configuration procedures.
@@ -232,9 +232,12 @@ void rand_seed(int seed);
    The m parameter is the length of the target field INCLUDING
    the terminating null.
 */
-#define strmcpy(dest,src,m) { strncpy(dest,src,m) ; dest[m-1] = '\000' ; }
+/* Since we're overwriting the last char, no need to copy it.
+   Doing this apparently squashes some warnings.
+*/
+#define strmcpy(dest,src,m) { strncpy(dest,src,m-1) ; dest[m-1] = '\000' ; }
 /* similarly */
-#define strmcat(dest,src,m) { strncat(dest,src,m) ; dest[m-1] = '\000' ; }
+#define strmcat(dest,src,m) { strncat(dest,src,m-1) ; dest[m-1] = '\000' ; }
 
 /* This is like strmcat, but it also quotes the string (in a system
    dependent way) for adding it to a shell command line.
